{# SPDX-FileCopyrightText: 2026 PythonWoods <dev@pythonwoods.dev> #}
{# SPDX-License-Identifier: Apache-2.0 #}
{#
  home.html — Template for marketing pages (landing, about).
  - Suppresses sidebar navigation
  Used by: index.md, about/index.md, about/*.md
#}
{% extends "main.html" %}

{% block site_nav %}{% endblock %}
