{# SPDX-FileCopyrightText: 2026 PythonWoods <dev@pythonwoods.dev> #}
{# SPDX-License-Identifier: Apache-2.0 #}
{% extends "base.html" %}

{% block extrahead %}
  {{ super() }}
  <link rel="icon" type="image/svg+xml" href="{{ 'assets/favicon/zenzic-icon.svg' | url }}">
  <link rel="icon" type="image/png" sizes="64x64" href="{{ 'assets/favicon/png/zenzic-icon-64.png' | url }}">
  <link rel="apple-touch-icon" sizes="180x180" href="{{ 'assets/favicon/png/zenzic-icon-180.png' | url }}">
  <meta property="og:image" content="{{ 'assets/social/social-card.png' | url }}">
  <meta property="og:image:width" content="1200">
  <meta property="og:image:height" content="630">
  <meta name="twitter:card" content="summary_large_image">
  <meta name="twitter:image" content="{{ 'assets/social/social-card.png' | url }}">
{% endblock %}
