# SPDX-FileCopyrightText: 2026 PythonWoods <dev@pythonwoods.dev>
# SPDX-License-Identifier: Apache-2.0
"""Zenzic — engineering-grade documentation linter for MkDocs sites."""

__version__ = "0.5.0a2"
