{# SPDX-FileCopyrightText: 2026 PythonWoods <dev@pythonwoods.dev> #}
{# SPDX-License-Identifier: Apache-2.0 #}
{% if config.theme.logo %}
  <img src="{{ config.theme.logo | url }}" alt="{{ config.site_name }}">
{% else %}
  {% set icon = config.theme.icon.logo or "material/library" %}
  {% include ".icons/" ~ icon ~ ".svg" %}
{% endif %}
